summaryrefslogtreecommitdiff
path: root/Build
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2016-04-27 21:54:13 +0000
committerKarl Berry <karl@freefriends.org>2016-04-27 21:54:13 +0000
commit4ca0e50699e2f4fc4dbe8b1dc4fe528a51b5429d (patch)
tree15c515e279a70c47939a7451b70ebfec6bbcb579 /Build
parent92b16675f5d3c1e9819112e099165b4dbc5f8a52 (diff)
context (27apr16)
git-svn-id: svn://tug.org/texlive/trunk@40787 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Build')
-rwxr-xr-xBuild/source/texk/texlive/linked_scripts/texlive/tlmgr.pl32
1 files changed, 27 insertions, 5 deletions
diff --git a/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl b/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
index b0ab912665c..9909f91af4f 100755
--- a/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
+++ b/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
@@ -1,13 +1,13 @@
#!/usr/bin/env perl
-# $Id: tlmgr.pl 40721 2016-04-24 13:05:42Z preining $
+# $Id: tlmgr.pl 40770 2016-04-26 21:42:20Z preining $
#
# Copyright 2008-2016 Norbert Preining
# This file is licensed under the GNU General Public License version 2
# or any later version.
#
-my $svnrev = '$Revision: 40721 $';
-my $datrev = '$Date: 2016-04-24 15:05:42 +0200 (Sun, 24 Apr 2016) $';
+my $svnrev = '$Revision: 40770 $';
+my $datrev = '$Date: 2016-04-26 23:42:20 +0200 (Tue, 26 Apr 2016) $';
my $tlmgrrevision;
my $prg;
if ($svnrev =~ m/: ([0-9]+) /) {
@@ -5773,8 +5773,21 @@ sub init_tlmedia {
$localtlpdb->save;
%repos = repository_to_array($location);
}
- # do the gpg stuff only when loading the remote tlpdb
- handle_gpg_config_settings();
+
+ # checksums and gpg stuff
+ if (TeXLive::TLCrypto::setup_checksum_method()) {
+ # it is only possible to do gpg verification if we can
+ # find a checksum method
+ # do the gpg stuff only when loading the remote tlpdb
+ handle_gpg_config_settings();
+ } else {
+ if (!$config{'no-checksums'}) {
+ tlwarn("Cannot determine a checksum method!\n");
+ tlwarn("Please install either Digest::SHA, openssl, or sha512sum.\n");
+ tlwarn("To silence this warning, set 'no-checksums' to 1 in the\n");
+ tlwarn("tlmgr configuration file.\n");
+ }
+ }
# check if we are only one tag/repo
if ($#tags == 0) {
@@ -6153,6 +6166,15 @@ sub load_options_from_config {
tlwarn("$prg: $fn: Unknown value for verify-downloads: $val\n");
}
+ } elsif ($key eq "no-checksums") {
+ if ($val eq "1") {
+ $config{"no-checksums"} = 1;
+ } elsif ($val eq "0") {
+ $config{"no-checksums"} = 0;
+ } else {
+ tlwarn("$prg: $fn: Unknown value for no-checksums: $val\n");
+ }
+
} elsif ($sysmode) {
# keys here are only allowed in sys mode
if ($key eq "allowed-actions") {